@@ -3,6 +3,8 @@
 import os, logging, time, json, copy
 import re
 from datetime import datetime, timedelta
+
+from django.forms import model_to_dict
 from rest_framework.views import APIView
 from rest_framework.response import Response
 from rest_framework import response
@@ -11,8 +13,7 @@ from rest_framework import generics
 from rest_framework.permissions import IsAuthenticated, IsAdminUser, AllowAny
 from django.utils.translation import gettext as tr
 
-
-from xj_user.models import BaseInfo
+from xj_user.models import BaseInfo, DetailInfo
 from xj_user.services.user_service import UserService, UserInfoSerializer
 
 logger = logging.getLogger(__name__)
@@ -55,7 +56,12 @@ class UserInfo(generics.UpdateAPIView):  # 或继承(APIView)
                 raise MyApiError(error_text, 6020)
             # print("> account_serv:", account_serv)
             user_info = account_serv
-
+            # avatar = None
+            # detailinfo = DetailInfo.objects.filter(user_id=user_info['user_id']).first()
+            # if detailinfo:
+            #     detailinfo = model_to_dict(detailinfo)
+            #     avatar = detailinfo['avatar']
+            # user_info['avatar'] = avatar
             res = {
                 'err': 0,
                 'msg': 'OK',
@@ -102,4 +108,4 @@ class MyApiError(Exception):
 
     def __str__(self):
         # repr()将对象转化为供解释器读取的形式。可省略
-        return repr(self.msg)
\ No newline at end of file
+        return repr(self.msg)
