@@ -8,6 +8,8 @@ import re
 from django.contrib.auth.hashers import make_password
 from django.db.models import Q
 import jwt
+from pathlib import Path
+from main.settings import BASE_DIR
 # from rest_framework.response import Response
 from rest_framework import response
 # from rest_framework import serializers
@@ -20,7 +22,12 @@ from rest_framework.views import APIView
 from config.config import Config
 # import random
 from xj_user.models import *
+from ..utils.j_config import JConfig
+from ..utils.j_dict import JDict
 
+module_dir = Path(__file__).parent.parent
+root_config = JDict(JConfig.get_section(str(BASE_DIR) + '/config.ini', 'xj_user', encode='utf-8-sig'))
+module_config = JDict(JConfig.get_section(str(module_dir) + '/config.ini', 'xj_user', encode='utf-8-sig'))
 
 # from datetime import datetime, timedelta
 # from django.contrib.auth.hashers import check_password
@@ -110,8 +117,10 @@ class UserRegister(APIView):
             # SECURITY WARNING: keep the secret key used in production secret!
             SECRET_KEY = 'django-insecure-l1$-m!u=!f9&o2$f(cm#dasus&a=5i1#+kh)090_=p%+==%9o1'
             JWT_SECRET_KEY = '@xzm2021!'
-
-            token = jwt.encode({'account': account}, Config.getIns().get('xj_user', "JWT_SECRET_KEY"))
+            c1 = root_config
+            c2 = module_config
+            jwt_secret_key = c1.jwt_secret_key or c2.jwt_secret_key or "@zxmxy2021!"
+            token = jwt.encode({'account': account}, jwt_secret_key)
             auth = {
                 'user_id': current_user.id,
                 'password': make_password(password, None, 'pbkdf2_sha1'),
