@@ -182,7 +182,7 @@ class ExtendField(models.Model):
 
     class Meta:
         db_table = 'user_extend_field'
-        verbose_name_plural = "03. 用户 - 扩展字段"
+        verbose_name_plural = "13. 用户 - 扩展字段"
 
     def __str__(self):
         return f"{self.field}"
@@ -290,7 +290,7 @@ class ContactBook(models.Model):
 
     class Meta:
         db_table = 'user_contact_book'
-        verbose_name_plural = "09. 用户 - 联系簿"
+        verbose_name_plural = "12. 用户 - 联系簿"
 
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
@@ -305,7 +305,7 @@ class UserSsoServe(models.Model):
 
     class Meta:
         db_table = 'user_sso_serve'
-        verbose_name_plural = "单点登录服务表"
+        verbose_name_plural = "14. 用户 - 单点登录服务表"
 
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
@@ -322,7 +322,7 @@ class UserSsoToUser(models.Model):
 
     class Meta:
         db_table = 'user_sso_to_user'
-        verbose_name_plural = "单点登录用户映射表"
+        verbose_name_plural = "15. 用户 - 单点登录用户映射表"
 
     def __str__(self):
         # return f"{self.user_name}({self.full_name})"
