@@ -415,12 +415,13 @@ class UserService:
         # 用户信息列表
 
     @staticmethod
-    def user_basic_message(user_id):
+    def user_basic_message(user_id=None, nickname=None):
         # user_basic_message = BaseInfo.objects.filter(id=user_id).first()
         res_data = {}
-        user_basic_message = BaseInfo.objects.filter(id=user_id).annotate(user_id=F("id")).first()
-        if not user_id:
-            return None, "user_id不能为空"
+        if user_id:
+            user_basic_message = BaseInfo.objects.filter(id=user_id).annotate(user_id=F("id")).first()
+        elif nickname:
+            user_basic_message = BaseInfo.objects.filter(nickname=nickname).annotate(user_id=F("id")).first()
         if user_basic_message:
             res_data = model_to_dict(user_basic_message)
             detailinfo = DetailInfo.objects.filter(user_id=user_id).first()
@@ -430,9 +431,8 @@ class UserService:
                 avatar = detail_info['avatar']
             res_data['avatar'] = avatar
             res_data['user_id'] = user_id
-            # res_data = user_basic_message.values("id", "user_name", "nickname", "full_name", "phone", "email",
-            #                                      "register_time")
-
+        # res_data = user_basic_message.values("id", "user_name", "nickname", "full_name", "phone", "email",
+        #                                      "register_time")
         return res_data, None
 
     @staticmethod
