@@ -8,6 +8,7 @@
 """
 from datetime import datetime, timedelta
 
+import requests
 from django.contrib.auth.hashers import make_password
 import jwt
 from pathlib import Path
@@ -16,6 +17,7 @@ from ..models import BaseInfo, Auth, UserSsoToUser
 from ..utils.model_handle import parse_model
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
+from ..utils.nickname_generate import gen_one_word_digit
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -38,6 +40,21 @@ expire_second = main_config_dict.expire_second or module_config_dict.expire_seco
 
 class UserSmsService:
 
+    def get_openid(self, code):
+        """
+        :param code（openid登录的code）:
+        :return:(err,data)
+        """
+        req_params = {
+            'appid': sub_appid,
+            'secret': sub_app_secret,
+            'js_code': code,
+            'grant_type': 'authorization_code',
+        }
+        user_info = requests.get('https://api.weixin.qq.com/sns/jscode2session', params=req_params, timeout=3,
+                                 verify=False)
+        return user_info.json()
+
     def phone_login(self, phone, login_code, sso_serve_id=None):
         current_user = BaseInfo.objects.filter(phone=phone).filter()
         current_user = parse_model(current_user)
@@ -46,7 +63,7 @@ class UserSmsService:
         if not current_user:
             base_info = {
                 'user_name': '',
-                'nickname': phone,
+                'nickname': gen_one_word_digit(),
                 'phone': phone,
                 'email': '',
                 'full_name': '请修改用户名',
