@@ -23,6 +23,7 @@ from ..models import BaseInfo, Auth, UserSsoToUser
 from ..utils.model_handle import parse_model
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
+from ..utils.nickname_generate import gen_one_word_digit
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -33,7 +34,6 @@ payment_main_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/conf
 payment_module_config_dict = JDict(JConfig.get_section(path=str(BASE_DIR) + "/config.ini", section="xj_payment"))
 
 sub_appid = payment_main_config_dict.wechat_merchant_app_id or payment_module_config_dict.wechat_merchant_app_id or ""
-
 sub_app_secret = payment_main_config_dict.wechat_merchant_app_secret or payment_module_config_dict.wechat_merchant_app_secret or ""
 
 app_id = main_config_dict.app_id or module_config_dict.app_id or ""
@@ -132,7 +132,7 @@ class WechatService:
         if not current_user:
             base_info = {
                 'user_name': '',
-                'nickname': phone,
+                'nickname': gen_one_word_digit(),
                 'phone': phone,
                 'email': '',
                 'full_name': '请修改用户名',
@@ -204,8 +204,8 @@ class WechatService:
         #     ttl = self.redis.ttl('access_token')
         #     return {"access_token": access_token.decode('utf-8'), 'expires_in': ttl, 'local': True}
         param = {
-            'appid': app_id,
-            'secret': app_secret,
+            'appid': sub_appid,
+            'secret': sub_app_secret,
             'grant_type': 'client_credential'
         }
         response = requests.get(self.wx_token_url, param).json()
