@@ -17,10 +17,10 @@ from .apis import user_login
 from .apis import user_login_short_message
 from .apis import user_login_wechat
 from .apis import user_password
-from .apis import user_permission
 from .apis import user_platform
 from .apis import user_register
 from .apis import user_sso_serve
+from .apis import user_statistics
 
 # from .apis import user_short_message
 
@@ -62,4 +62,6 @@ urlpatterns = [
 
     re_path(r'^sso_serve/?$', user_sso_serve.UserSsoServe.as_view(), ),
 
+    re_path(r'^statistics/?$', user_statistics.UserStatisticsAPI.as_view(), ),
+
 ]
